@@ -3,7 +3,9 @@ import sys
 
 from subprocess import check_output, CalledProcessError
 
-from commands import create, scale, destroy
+from commands.create import create
+from commands.scale import scale
+from commands.destroy import destroy
 
 def check_validity():
     """
